diff src/screen.c @ 9428:0c7f47088e55 v7.4.1995

commit https://github.com/vim/vim/commit/9d5d3c9c4468ad76f16b50eabd3d9e7eab2ed44d Author: Bram Moolenaar <Bram@vim.org> Date: Thu Jul 7 16:43:02 2016 +0200 patch 7.4.1995 Problem: GUI: cursor drawn in wrong place if a timer callback causes a screen update. (David Samvelyan) Solution: Also redraw the cursor when it's blinking and on.
author Christian Brabandt <cb@256bit.org>
date Thu, 07 Jul 2016 16:45:08 +0200
parents b6472fd9f5ba
children e08c8502d7ce
line wrap: on
line diff
--- a/src/screen.c
+++ b/src/screen.c
@@ -432,9 +432,9 @@ redraw_after_callback(void)
 #ifdef FEAT_GUI
     if (gui.in_use)
     {
-	/* Don't update the cursor while it is blinking, it will get
-	 * updated soon and this avoids interrupting the blinking. */
-	if (!gui_mch_is_blinking())
+	/* Don't update the cursor when it is blinking and off to avoid
+	 * flicker. */
+	if (!gui_mch_is_blink_off())
 	    gui_update_cursor(FALSE, FALSE);
 	gui_mch_flush();
     }